---
title: <span class="badge object-type-scalar"></span> RecordsPerSecond
---
# <span class="badge object-type-scalar"></span> RecordsPerSecond

Throughput: records/sec (rps)

## Definition

```python
# Throughput: records/sec (rps)
RecordsPerSecond: typing.Literal["recps"] = "recps"
```
